@@ -621,10 +621,10 @@ def predict_goals(pbp):
     #UE_MODEL = pickle.load(open(ue_file, 'rb'))
 
     EV_MODEL = pd.read_pickle(ev_file)
-    PP_MODEL = pd.read_pickle(pp_File)
-    SH_MODEL = pd.read_pickle(sh_File)
-    EN_MODEL = pd.read_pickle(en_File)
-    UE_MODEL = pd.read_pickle(ue_File)
+    PP_MODEL = pd.read_pickle(pp_file)
+    SH_MODEL = pd.read_pickle(sh_file)
+    EN_MODEL = pd.read_pickle(en_file)
+    UE_MODEL = pd.read_pickle(ue_file)
     
     model_df = xG_prep(pbp)
 
